<?php
/**
 * Filter to change invoice strings.
 */
if ( ! function_exists('woo_invoice_free_filter_label') ) {
    function woo_invoice_free_filter_label( $label, $order, $template ) {
        return apply_filters(
            'woo_invoice_filter_template_label',
            __($label, 'webappick-pdf-invoice-for-woocommerce'), //phpcs:ignore
            $order,
            $template
        );
    }
}

/**
 * Function to switch language according to order language.
 * @param $language_code
 * @param bool $cookie_lang
 */
function woo_invoice_free_switch_language_callback( $language_code, $cookie_lang = true ) {
    if ( ! empty($language_code) ) {
        if ( class_exists('SitePress', false) ) {
            // WPML Switch Language.
            global $sitepress;
            if ( $sitepress->get_current_language() !== $language_code ) {
                $sitepress->switch_lang($language_code, $cookie_lang);
            }
        }
        // when polylang plugin is activated
        if ( defined('POLYLANG_BASENAME') || function_exists('PLL') ) {
            if ( pll_current_language() !== $language_code ) {
                PLL()->curlang = PLL()->model->get_language($language_code);
            }
        }
    }
}

/**
 * Function to restore language.
 */
function woo_invoice_free_restore_language_callback() {
    $language_code = '';
    if ( class_exists('SitePress', false) ) {
        // WPML restore Language.
        global $sitepress;
        $language_code = $sitepress->get_default_language();
    }

    // when polylang plugin is activated
    if ( defined('POLYLANG_BASENAME') || function_exists('PLL') ) {
        $language_code = pll_default_language();
    }
    /**
     * Filter to hijack Default Language code before restore
     *
     * @param string $language_code
     */

    if ( ! empty($language_code) ) {
        woo_invoice_free_switch_language_callback($language_code);
    }
}

/**
 * Reload text domain after switch language.
 */
function woo_invoice_free_reload_text_domain() {
    load_plugin_textdomain(
        'webappick-pdf-invoice-for-woocommerce',
        false,
        dirname(WOO_INVOICE_PRO_PLUGIN_BASE_NAME) . '/languages/'
    );

}

if ( ! function_exists('challan_order_meta_query') ) {
    /**
     * @return array|object|null
     */
    function challan_order_meta_query(){
        global $wpdb;
        $order_meta_query_arr = $wpdb->get_results(
            "SELECT $wpdb->postmeta.meta_key FROM $wpdb->postmeta
                                    LEFT JOIN $wpdb->posts ON $wpdb->postmeta.post_id = $wpdb->posts.id
                                    WHERE $wpdb->posts.post_type = 'shop_order'
                                    GROUP BY $wpdb->postmeta.meta_key"
        );
        $order_meta_query = array();
        $order_meta_query = $order_meta_query_arr;

        return $order_meta_query;
    }
}


if ( ! function_exists('challan_product_meta_query') ) {
    /**
     * @return array|object|null
     */
    function challan_product_meta_query(){
        global $wpdb;
        // $meta_query = $wpdb->get_results( "SELECT * FROM $wpdb->postmeta GROUP BY meta_key" );
        $product_meta_query = $wpdb->get_results(
            "SELECT $wpdb->postmeta.meta_key, $wpdb->postmeta.meta_id FROM $wpdb->postmeta
                                    LEFT JOIN $wpdb->posts ON $wpdb->postmeta.post_id = $wpdb->posts.id
                                    WHERE $wpdb->posts.post_type = 'product'
                                    GROUP BY $wpdb->postmeta.meta_key"
        );

        return $product_meta_query;
    }
}

if ( ! function_exists('challan_item_meta_query') ) {
    /**
     * @return array|object|null
     */
    function challan_item_meta_query(){
        global $wpdb;
        $item_meta = $wpdb->get_results(
            "SELECT  $wpdb->order_itemmeta.meta_id ,$wpdb->order_itemmeta.meta_key,$wpdb->order_itemmeta.meta_value
        FROM $wpdb->order_itemmeta GROUP BY $wpdb->order_itemmeta.meta_key");

        return $item_meta;
    }
}

if ( ! function_exists('challan_order_meta_data_position') ) {
    /**
     * @return string[].
     */
    function challan_order_meta_data_position(){
        $order_meta_position_arr = array(
            'after_order_data'          => 'After order data',
            'before_order_data'         => 'Before order data',
            'before_billing_address'    => 'Before billing address',
            'after_billing_address'     => 'After billing address',
            'before_shipping_address'   => 'Before shipping address',
            'after_shipping_address'    => 'After shipping address',
        );

        return $order_meta_position_arr;
    }
}



